@@ -1,3 +1,21 @@
+/*
+ * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1, or (at your option)
+ * any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
+ *
+ */
+
 /**
  * 农历（阴历）万年历
  * LunarCalendar
@@ -73,7 +91,7 @@
 		zodiac: ['鼠','牛','虎','兔','龙','蛇','马','羊','猴','鸡','狗','猪'], //对应地支十二生肖
 		solarTerm: ['小寒', '大寒', '立春', '雨水', '惊蛰', '春分', '清明', '谷雨', '立夏', '小满', '芒种', '夏至', '小暑', '大暑', '立秋', '处暑', '白露', '秋分', '寒露', '霜降', '立冬', '小雪', '大雪','冬至'], //二十四节气
         monthCn: ['正', '二', '三', '四', '五', '六', '七', '八', '九', '十', '十一', '十二'],
-		dateCn: ['初一', '初二', '初三', '初四', '初五', '初六', '初七', '初八', '初九', '初十', '十一', '十二', '十三', '十四', '十五', '十六', '十七', '十八', '十九', '二十', '廿一', '廿二', '廿三', '廿四', '廿五', '廿六', '廿七', '廿八', '廿九', '三十', '卅一']
+		dateCn: ['初一', '初二', '初三', '初四', '初五', '初六', '初七', '初八', '初九', '初十', '十一', '十二', '十三', '十四', '十五', '十六', '十七', '十八', '十九', '二十', '廿一', '廿二', '廿三', '廿四', '廿五', '廿六', '廿七', '廿八', '廿九', '三十', '初一']
 	};
 	
 	//中国节日放假安排，外部设置，0无特殊安排，1工作，2放假
@@ -317,6 +335,8 @@
 		var monthDays = lunarYearDays.monthDays;
 		var tempDays = 0;
 		var month = 0;
+		var lunarName = 0;
+		end = Math.round(end);
 		for(var i=0;i<monthDays.length;i++){
 			tempDays += monthDays[i];
 			if(tempDays > end){
@@ -325,8 +345,9 @@
 				break;
 			}
 		}
-		
-		return [year,month,end - tempDays + 1];
+		lunarName = Math.round(end - tempDays + 1);
+		return [year,month,lunarName];
+		// return [year,month,end - tempDays + 1];
 	};
 
 	/**
@@ -549,7 +570,7 @@
 		//除夕
 		if(lunarDate[1] == lunarMonthDays.length-1 && lunarDate[2]==lunarMonthDays[lunarMonthDays.length-1]){
 			lunarFtv = lunarFestival['d0100'];
-		}else if(lunarLeapMonth>0 && lunarDate[1]>lunarLeapMonth){
+		}else if(lunarLeapMonth>0 && lunarDate[1]>=lunarLeapMonth){
 			lunarFtv = lunarFestival[formateDayD4(lunarDate[1]-1,lunarDate[2])];
 		}else{
 			lunarFtv = lunarFestival[formateDayD4(lunarDate[1],lunarDate[2])];
@@ -584,13 +605,13 @@
 	 * @param {Number} year,month 公历年，月
 	 * @param {Boolean} fill 是否用上下月数据补齐首尾空缺，首例数据从周日开始
 	 */
-	function calendar(_year,_month,fill){
+	function calendar(_year,_month,fill,mode){
 		var inputDate = formateDate(_year,_month);
 		if(inputDate.error)return inputDate;
 		var year = inputDate.year;
 		var month = inputDate.month;
 		
-		var calendarData = solarCalendar(year,month+1,fill);
+		var calendarData = solarCalendar(year,month+1,fill,mode);
 		for(var i=0;i<calendarData.monthData.length;i++){
 			var cData = calendarData.monthData[i];
 			var lunarData = solarToLunar(cData.year,cData.month,cData.day);
@@ -605,7 +626,7 @@
 	 * @param {Number} year,month 公历年，月
 	 * @param {Boolean} fill 是否用上下月数据补齐首尾空缺，首例数据从周日开始 (7*6阵列)
 	 */
-	function solarCalendar(_year,_month,fill){
+	function solarCalendar(_year,_month,fill,mode){
 		var inputDate = formateDate(_year,_month);
 		if(inputDate.error)return inputDate;
 		var year = inputDate.year;
@@ -623,11 +644,30 @@
 		res.monthData = creatLenArr(year,month+1,res.monthDays,1);
 
 		if(fill){
-			if(res.firstDay > 0){ //前补
+			if(res.firstDay != mode){ //前补
 				var preYear = month-1<0 ? year-1 : year;
 				var preMonth = month-1<0 ? 11 : month-1;
 				preMonthDays = getSolarMonthDays(preYear,preMonth);
-				preMonthData = creatLenArr(preYear,preMonth+1,res.firstDay,preMonthDays-res.firstDay+1);
+				if(mode === 0)
+				{
+					preMonthData = creatLenArr(preYear,preMonth+1,res.firstDay,preMonthDays-res.firstDay+1);
+				}
+
+				//prev version
+				//preMonthData = creatLenArr(preYear,preMonth+1,res.firstDay,preMonthDays-res.firstDay+1);
+				// res.monthData = preMonthData.concat(res.monthData);
+
+				else
+				{
+					if(res.firstDay > 0)//每周从周一开始,一号是星期一至星期六，补 n-1天
+					{
+						preMonthData = creatLenArr(preYear,preMonth+1,res.firstDay -1 ,preMonthDays-(res.firstDay-1)+1);
+					}
+					else//每周从周一开始,一号是星期一至星期六 补6天
+					{
+						preMonthData = creatLenArr(preYear,preMonth+1,res.firstDay + 6 ,preMonthDays-(res.firstDay + 6)+1);
+					}
+				}
 				res.monthData = preMonthData.concat(res.monthData);
 			}
 			
